@@ -8,27 +8,28 @@ examples/fontdlg.pl - An alternate font selection window
 
 =head1 FEATURES
 
-Demonstrates Prima font API and its usage.
+Demonstrates Prima font API
 
 Note the inability to set a font with a particular size and width factor in one
-call ( in $re_sample sub ). A font size and width is accepted, however.
+call ( in the $re_sample sub ). A font height and width together are accepted, however.
 
 Tests the Prima font interface implementation. A constant pain here is the
-correspondence of a font metrics before and after the font load.  X is known
-for the problem, that can not be solved easily and without certain compromises.
-See L<prima-gp-problems> manpage for details.
+correspondence of font metrics before and after the font load.  X11 is
+particularly known for the problem where bitmap fonts don't match, and this
+problem can not be solved easily and without certain compromises.  See
+L<prima-gp-problems> manpage for details.
 
-Note the left-mouse drag effect from a font screen widget.
+Note the left-mouse drag effect from the font widget.
 
 =cut
 
-
 use strict;
 use warnings;
+use utf8;
 use Carp;
 use Prima;
 use Prima::Application name => "Font Dialog";
-use Prima qw(Lists Sliders Buttons FileDialog);
+use Prima qw(Lists Sliders Buttons Dialog::FileDialog);
 use Encode;
 
 # try to use perl5.8 glyph names
@@ -412,7 +413,7 @@ sub create_info_window
 	my $w = shift;
 	my $f = $w-> Example-> font;
 	my $ww = Prima::Window-> create(
-		size => [ 500, $f-> height * 3 + $f-> externalLeading + $f-> descent + 450 ],
+		size => [ 500, $f-> height * 3 + $f-> externalLeading + $f-> descent + 482 ],
 		font => $f,
 		text => $f-> size.'.['.$f-> height.'x'.$f-> width.']'.$f-> name,
 		onPaint => sub {
@@ -497,6 +498,8 @@ sub create_info_window
 			$p-> text_out( 'last char           : '.$m-> {lastChar }, 2, $sd); $sd -= $fh;
 			$p-> text_out( 'break char          : '.$m-> {breakChar}, 2, $sd); $sd -= $fh;
 			$p-> text_out( 'default char        : '.$m-> {defaultChar}, 2, $sd); $sd -= $fh;
+			$p-> text_out( 'underline position  : '.$m-> {underlinePosition}, 2, $sd); $sd -= $fh;
+			$p-> text_out( 'underline thickness : '.$m-> {underlineThickness}, 2, $sd); $sd -= $fh;
 			$p-> text_out( 'family              : '.$m-> {family   }, 2, $sd); $sd -= $fh;
 			$p-> text_out( 'face name           : '.$cachedFacename, 2, $sd); $sd -= $fh;
 			unless ( $p-> Languages-> visible ) {
@@ -504,7 +507,7 @@ sub create_info_window
 				my $em = $p->get_text_width('m');
 				$l->origin( 2 + $em * 22, $sd );
 				$l->font( $p-> font );
-				$l->size( $em * 10, $fh);
+				$l->size( $em * 30, $fh);
 				$l->show;
 			}
 			$p-> text_out( 'languages           : ', 2, $sd); $sd -= $fh;
@@ -585,6 +588,7 @@ sub create_info_window
 			push @{$ranges[-1]}, $_ :
 			push @ranges, [$_];
 	}
+	pop @ranges unless @ranges and @{$ranges[0]};
 	@ranges = sort { $a->[0] <=> $b-> [0] } @ranges;
 	my %charmap;
 	my $count = 0;
@@ -594,7 +598,7 @@ sub create_info_window
 	my $ih = int($f-> height * 1.5);
 	my $l = $ww-> insert( AbstractListViewer =>
 		origin => [0,0],
-		size   => [$ww-> width, $ww-> height - $f-> height - $f-> externalLeading - $f-> descent - 360],
+		size   => [$ww-> width, $ww-> height - $f-> height - $f-> externalLeading - $f-> descent - 400],
 		growMode => gm::Client,
 		font     => $f,
 		multiColumn => 1,
@@ -636,6 +640,7 @@ sub create_info_window
 	);
 	$l-> count( $count);
 	$ww-> select;
+	return $ww;
 }
 
 $displayRes = ($w-> resolution)[1];
@@ -758,7 +763,7 @@ $w-> insert( Button =>
 	name   => 'Load',
 	font   => { height => 20 * $scaling },
 	onClick   => sub {
-		my $d = Prima::FileDialog-> new;
+		my $d = Prima::Dialog::FileDialog-> new;
 		my $f = $d->execute;
 		return unless defined $f;
 		my $error = '';
@@ -795,7 +800,7 @@ $csl-> insert( Button =>
 	onClick => sub { $_[0]-> owner-> value(0); },
 );
 
-my $rg = $w-> insert( RadioGroup =>
+my $rg = $w-> insert( GroupBox =>
 	origin      => [ 25, 525],
 	size        => [ 445, 58],
 	name        => 'Pitch',
@@ -822,7 +827,7 @@ $rg-> insert( Radio =>
 	onClick =>  sub { $fpitch = fp::Variable; &$re_sample; },
 );
 
-my $rg2 = $w-> insert( RadioGroup =>
+my $rg2 = $w-> insert( GroupBox =>
 	origin      => [ 25, 460],
 	size        => [ 445, 58],
 	name        => 'Vector',
@@ -968,6 +973,8 @@ $w-> insert( Widget =>
 
 &$re_size(1);
 &$re_sample;
+#$w->NameList->focusedItem($#fontItems);
+#create_info_window($w)->size(800, 800);
 }
 
 run;
